@@ -21,8 +21,7 @@ from importlib import resources
 
 from SPARQLWrapper import SPARQLWrapper, RDFXML
 from pyshex import ShExEvaluator
-from rdflib import RDF, Namespace, ConjunctiveGraph, Graph, XSD
-from rdflib.term import _toPythonMapping
+from rdflib import RDF, Namespace, ConjunctiveGraph, Graph
 from typing import TYPE_CHECKING
 
 from oc_ocdm.graph.graph_entity import GraphEntity
@@ -47,7 +46,7 @@ class Reader(object):
             ctx_file_path: Any = self.context_map[context_url]
             if type(ctx_file_path) == str and os.path.isfile(ctx_file_path):
                 # This expensive operation is done only when it's really needed
-                with open(ctx_file_path, "rt") as ctx_f:
+                with open(ctx_file_path, 'rt', encoding='utf-8') as ctx_f:
                     self.context_map[context_url] = json.load(ctx_f)
 
         if repok is None:
@@ -66,9 +65,6 @@ class Reader(object):
 
         loaded_graph: Optional[ConjunctiveGraph] = None
         if os.path.isfile(rdf_file_path):
-            Reader._hack_dates()
-            # The line above has been added for handling gYear and gYearMonth correctly.
-            # More info at https://github.com/RDFLib/rdflib/issues/806.
 
             try:
                 loaded_graph = self._load_graph(rdf_file_path)
@@ -83,13 +79,6 @@ class Reader(object):
 
         return loaded_graph
 
-    @staticmethod
-    def _hack_dates() -> None:
-        if XSD.gYear in _toPythonMapping:
-            _toPythonMapping.pop(XSD.gYear)
-        if XSD.gYearMonth in _toPythonMapping:
-            _toPythonMapping.pop(XSD.gYearMonth)
-
     def _load_graph(self, file_path: str) -> ConjunctiveGraph:
         formats: List[str] = ["json-ld", "rdfxml", "turtle", "trig", "nt11", "nquads"]
 
@@ -99,7 +88,7 @@ class Reader(object):
         for cur_format in formats:
             try:
                 if cur_format == "json-ld":
-                    with open(file_path, "rt") as f:
+                    with open(file_path, 'rt', encoding='utf-8') as f:
                         json_ld_file: Any = json.load(f)
                         if isinstance(json_ld_file, dict):
                             json_ld_file: List[Any] = [json_ld_file]
@@ -287,6 +276,6 @@ class Reader(object):
             imported_entities: List[GraphEntity] = Reader.import_entities_from_graph(g_set, result,
                                                                                      resp_agent, enable_validation)
             if len(imported_entities) <= 0:
-                raise ValueError("The required entity was not found or was not recognized as a proper OCDM entity.")
+                raise ValueError("The requested entity was not found or was not recognized as a proper OCDM entity.")
             else:
                 return imported_entities[0]
