@@ -15,6 +15,10 @@
 # SOFTWARE.
 from __future__ import annotations
 
+import os
+import json
+from datetime import datetime
+from rdflib import ConjunctiveGraph
 from SPARQLWrapper import SPARQLWrapper
 from typing import TYPE_CHECKING
 
@@ -23,6 +27,8 @@ from oc_ocdm.graph.graph_entity import GraphEntity
 from oc_ocdm.metadata.metadata_entity import MetadataEntity
 from oc_ocdm.reader import Reader
 from oc_ocdm.support.query_utils import get_update_query
+from oc_ocdm.support.support import find_paths
+from oc_ocdm.support.reporter import Reporter
 
 if TYPE_CHECKING:
     from typing import Dict, List, Tuple, Any, Optional, Set
@@ -30,14 +36,6 @@ if TYPE_CHECKING:
     from oc_ocdm.abstract_entity import AbstractEntity
     from oc_ocdm.abstract_set import AbstractSet
 
-from oc_ocdm.support.reporter import Reporter
-import os
-from rdflib import ConjunctiveGraph
-import json
-from datetime import datetime
-import io
-from oc_ocdm.support.support import find_paths
-
 
 class Storer(object):
 
@@ -71,7 +69,7 @@ class Storer(object):
                 ctx_file_path: Any = self.context_map[context_url]
                 if type(ctx_file_path) == str and os.path.isfile(ctx_file_path):
                     # This expensive operation is done only when it's really needed
-                    with open(ctx_file_path, "rt") as ctx_f:
+                    with open(ctx_file_path, 'rt', encoding='utf-8') as ctx_f:
                         self.context_map[context_url] = json.load(ctx_f)
 
         if repok is None:
@@ -84,7 +82,7 @@ class Storer(object):
         else:
             self.reperr: Reporter = reperr
 
-    def store_graphs_in_file(self, file_path: str, context_path: str) -> None:
+    def store_graphs_in_file(self, file_path: str, context_path: str = None) -> None:
         self.repok.new_article()
         self.reperr.new_article()
         self.repok.add_sentence("Store the graphs into a file: starting process")
@@ -95,9 +93,9 @@ class Storer(object):
 
         self._store_in_file(cg, file_path, context_path)
 
-    def _store_in_file(self, cur_g: ConjunctiveGraph, cur_file_path: str, context_path: str) -> None:
+    def _store_in_file(self, cur_g: ConjunctiveGraph, cur_file_path: str, context_path: str = None) -> None:
         # Note: the following lines from here and until 'cur_json_ld' are a sort of hack for including all
-        # the triples of the input graph into the final stored file. Some how, some of them are not written
+        # the triples of the input graph into the final stored file. Somehow, some of them are not written
         # in such file otherwise - in particular the provenance ones.
         new_g: ConjunctiveGraph = ConjunctiveGraph()
         for s, p, o in cur_g.triples((None, None, None)):
@@ -111,7 +109,7 @@ class Storer(object):
         if self.output_format == "json-ld":
             if context_path is not None and context_path in self.context_map:
                 cur_json_ld: Any = json.loads(
-                    new_g.serialize(format="json-ld", context=self.context_map[context_path]).decode("utf-8"))
+                    new_g.serialize(format="json-ld", context=self.context_map[context_path]))
 
                 if isinstance(cur_json_ld, dict):
                     cur_json_ld["@context"] = context_path
@@ -119,16 +117,16 @@ class Storer(object):
                     for item in cur_json_ld:
                         item["@context"] = context_path
             else:
-                cur_json_ld: Any = json.loads(new_g.serialize(format="json-ld").decode("utf-8"))
+                cur_json_ld: Any = json.loads(new_g.serialize(format="json-ld"))
 
-            with open(cur_file_path, "wt", encoding='utf-8') as f:
+            with open(cur_file_path, 'wt', encoding='utf-8') as f:
                 json.dump(cur_json_ld, f, indent=4, ensure_ascii=False)
         else:
             new_g.serialize(cur_file_path, format=self.output_format, encoding="utf-8")
 
         self.repok.add_sentence(f"File '{cur_file_path}' added.")
 
-    def store_all(self, base_dir: str, base_iri: str, context_path: str) -> List[str]:
+    def store_all(self, base_dir: str, base_iri: str, context_path: str = None) -> List[str]:
         self.repok.new_article()
         self.reperr.new_article()
 
@@ -146,7 +144,7 @@ class Storer(object):
 
         return stored_graph_path
 
-    def store(self, entity: AbstractEntity, base_dir: str, base_iri: str, context_path: str,
+    def store(self, entity: AbstractEntity, base_dir: str, base_iri: str, context_path: str = None,
               already_processed: Dict[str, ConjunctiveGraph] = None,
               store_now: bool = True) -> Optional[Dict[str, ConjunctiveGraph]]:
         self.repok.new_article()
@@ -210,7 +208,7 @@ class Storer(object):
         except Exception as e:
             self.reperr.add_sentence(f"[1] It was impossible to store the RDF statements in {cur_file_path}. {e}")
 
-    def upload_and_store(self, base_dir: str, triplestore_url: str, base_iri: str, context_path: str,
+    def upload_and_store(self, base_dir: str, triplestore_url: str, base_iri: str, context_path: str = None,
                          batch_size: int = 10) -> None:
         stored_graph_path: List[str] = self.store_all(base_dir, base_iri, context_path)
 
@@ -221,7 +219,7 @@ class Storer(object):
             for file_path in stored_graph_path:
                 if file_path is not None:
                     # Create a marker for the file not uploaded in the triplestore
-                    open(f"{file_path}.notuploaded", "wt").close()
+                    open(f'{file_path}.notuploaded', 'wt', encoding='utf-8').close()
                     self.reperr.add_sentence("[2] "
                                              f"The statements contained in the JSON-LD file '{file_path}' "
                                              "were not uploaded into the triplestore.")
@@ -325,7 +323,7 @@ class Storer(object):
                         os.makedirs(tp_err_dir)
                     cur_file_err: str = tp_err_dir + os.sep + \
                         datetime.now().strftime('%Y-%m-%d-%H-%M-%S-%f_not_uploaded.txt')
-                    with io.open(cur_file_err, "w", encoding="utf-8") as f:
+                    with open(cur_file_err, 'wt', encoding='utf-8') as f:
                         f.write(query_string)
 
         return False
